package com.qmth.paper.library.business.service;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.IService;
import com.qmth.paper.library.business.bean.params.PaperScanTaskParam;
import com.qmth.paper.library.business.bean.result.PaperScanTaskDetailResult;
import com.qmth.paper.library.business.bean.result.PaperScanTaskResult;
import com.qmth.paper.library.business.entity.PaperScanTask;
import com.qmth.paper.library.common.entity.SysUser;

import java.util.List;

/**
 * <p>
 * 扫描任务表 服务类
 * </p>
 */
public interface PaperScanTaskService extends IService<PaperScanTask> {
    /**
     * 扫描任务分页查询
     *
     * @param courseName  课程名称
     * @param teacherName 任课教师
     * @param pageNumber  分页页数
     * @param pageSize    分页容量
     * @param requestUser 请求用户
     * @return 分页结果
     */
    IPage<PaperScanTaskResult> paperScanTaskPage(String courseName, String teacherName, int pageNumber, int pageSize, SysUser requestUser);

    /**
     * 扫描任务编辑
     *
     * @param paperScanTaskParam 扫描任务参数
     * @param requestUser        请求用户
     * @return 扫描任务id
     */
    Long editPaperScanTask(PaperScanTaskParam paperScanTaskParam, SysUser requestUser);

    /**
     * 扫描任务批量删除
     *
     * @param idList      扫描任务id集合
     * @param requestUser 请求的用户
     */
    void deletePaperScanTaskByIdList(List<Long> idList, SysUser requestUser);

    /**
     * 扫描员模板导出
     *
     * @param requestUser 请求的用户
     */
    void exportScanner(SysUser requestUser) throws Exception;

    /**
     * 根据扫描任务id分页查询扫描任务详情
     *
     * @param paperScanTaskId 扫描任务id
     * @param requestUser     请求的用户
     * @return 扫描任务详情分页结果
     */
    IPage<PaperScanTaskDetailResult> findPaperScanTaskDetailPageByTaskId(Long paperScanTaskId, int pageNumber, int pageSize, SysUser requestUser);

    /**
     * 清除扫描任务数据
     *
     * @param paperScanTaskId 扫描任务id
     * @param requestUser     请求用户
     */
    void clearScanData(Long paperScanTaskId, SysUser requestUser);


    List<PaperScanTask> listByPaperArchivesId(Long id);
}
